@@ -17,18 +17,18 @@
 ********************************************************************************
 """
 
-from abc import ABCMeta, abstractmethod
-from .commException import CommException
-from .ledgerWrapper import wrapCommandAPDU, unwrapResponseAPDU
-from .Dongle import *
 from binascii import hexlify
-import time
+import hid
 import os
-import sys
-from .commU2F import getDongle as getDongleU2F
+import time
+
+from .commException import CommException
 from .commHTTP import getDongle as getDongleHTTP
 from .commTCP import getDongle as getDongleTCP
-import hid
+from .commU2F import getDongle as getDongleU2F
+from .Dongle import Dongle, DongleWait, TIMEOUT
+from .ledgerWrapper import wrapCommandAPDU, unwrapResponseAPDU
+
 
 APDUGEN=None
 if "APDUGEN" in os.environ and len(os.environ["APDUGEN"]) != 0:
@@ -70,11 +70,11 @@ class HIDDongleHIDAPI(Dongle, DongleWait):
 
 	def exchange(self, apdu, timeout=TIMEOUT):
 		if APDUGEN:
-			print("%s" % hexstr(apdu))
+			print(apdu.hex())
 			return
 
 		if self.debug:
-			print("HID => %s" % hexstr(apdu))
+			print("HID => %s" % apdu.hex())
 		if self.ledger:
 			apdu = wrapCommandAPDU(0x0101, apdu, 64)		
 		padSize = len(apdu) % 64
@@ -82,7 +82,7 @@ class HIDDongleHIDAPI(Dongle, DongleWait):
 		if padSize != 0:
 			tmp.extend([0] * (64 - padSize))
 		offset = 0
-		while(offset != len(tmp)):
+		while offset != len(tmp):
 			data = tmp[offset:offset + 64]
 			data = bytearray([0]) + data
 			if self.device.write(data) < 0:
@@ -98,7 +98,7 @@ class HIDDongleHIDAPI(Dongle, DongleWait):
 				dataLength += 2
 				if dataLength > 62:
 					remaining = dataLength - 62
-					while(remaining != 0):
+					while remaining != 0:
 						if remaining > 64:
 							blockLength = 64
 						else:
@@ -125,7 +125,7 @@ class HIDDongleHIDAPI(Dongle, DongleWait):
 		sw = (result[swOffset] << 8) + result[swOffset + 1]
 		response = result[dataStart : dataLength + dataStart]
 		if self.debug:
-			print("HID <= %s%.2x" % (hexstr(response), sw))
+			print("HID <= %s%.2x" % (response.hex(), sw))
 		if sw != 0x9000 and (sw & 0xFF00) != 0x6100 and (sw & 0xFF00) != 0x6C00:
 			possibleCause = "Unknown reason"
 			if sw == 0x6982:
@@ -177,11 +177,11 @@ class DongleSmartcard(Dongle):
 
 	def exchange(self, apdu, timeout=TIMEOUT):
 		if self.debug:
-			print("SC => %s" % hexstr(apdu))
+			print("SC => %s" % apdu.hex())
 		response, sw1, sw2 = self.device.transmit(toBytes(hexlify(apdu)))
 		sw = (sw1 << 8) | sw2
 		if self.debug:
-			print("SC <= %s%.2x" % (hexstr(response).replace(" ", ""), sw))
+			print("SC <= %s%.2x" % (response.hex(), sw))
 		if sw != 0x9000 and (sw & 0xFF00) != 0x6100 and (sw & 0xFF00) != 0x6C00:
 			raise CommException("Invalid status %04x" % sw, sw, bytearray(response))
 		return bytearray(response)
