@@ -45,20 +45,14 @@
 
 import os
 import traceback
-from abc import ABCMeta, abstractmethod
-from .ledgerWrapper import wrapCommandAPDU, unwrapResponseAPDU
-from binascii import hexlify
-from .Dongle import *
+from .Dongle import Dongle, DongleWait
 
-import binascii
 import time
-import sys
 import hid
 from u2flib_host.device import U2FDevice
 from u2flib_host.yubicommon.compat import byte2int, int2byte
-from u2flib_host.constants import INS_ENROLL, INS_SIGN
-from u2flib_host import u2f, exc
-from u2flib_host.utils import websafe_decode, websafe_encode
+from u2flib_host.constants import INS_SIGN
+from u2flib_host import exc
 from hashlib import sha256
 
 from .commException import CommException
@@ -99,7 +93,7 @@ U2FHID_YUBIKEY_DEVICE_CONFIG = U2F_VENDOR_FIRST
 STAT_ERR = 0xbf
 
 def _read_timeout(dev, size, timeout=TIMEOUT):
-    if (timeout > 0):
+    if timeout > 0:
       timeout += time.time()
     while timeout == 0 or time.time() < timeout:
         resp = dev.read(size)
@@ -223,9 +217,9 @@ class U2FTunnelDongle(Dongle, DongleWait):
 
   def exchange(self, apdu, timeout=TIMEOUT):
     if self.debug:
-      print("U2F => %s" % hexstr(apdu))
+      print("U2F => %s" % apdu.hex())
 
-    if (len(apdu)>=256):
+    if len(apdu) >= 256:
       raise CommException("Too long APDU to transport")  
     
     # wrap apdu
@@ -258,11 +252,11 @@ class U2FTunnelDongle(Dongle, DongleWait):
         raise e
 
       if self.debug:
-        print("U2F <= %s%.2x" % (hexstr(response), 0x9000))
+        print("U2F <= %s%.2x" % (response.hex(), 0x9000))
 
       # check replied status words of the command (within the APDU tunnel)
-      if hexstr(response[-2:]) != "9000":
-        raise CommException("Invalid status words received: " + hexstr(response[-2:]));
+      if response[-2:] != b"\x90\x00":
+        raise CommException("Invalid status words received: " + response[-2:].hex())
       else:
         break
 
