@@ -21,7 +21,7 @@ import argparse
 
 def get_argparser():
 	parser = argparse.ArgumentParser(description="Delete the app with the specified name.")
-	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int)
+	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int, default=0x31000002)
 	parser.add_argument("--appName", help="The name of the application to delete", action='append')
 	parser.add_argument("--appHash", help="Set the application hash")
 	parser.add_argument("--rootPrivateKey", help="A private key used to establish a Secure Channel (hex encoded)")
@@ -39,7 +39,6 @@ if __name__ == '__main__':
 	from .deployed import getDeployedSecretV1, getDeployedSecretV2
 	from .hexLoader import HexLoader
 	import binascii
-	import sys
 
 	args = get_argparser().parse_args()
 
@@ -48,21 +47,12 @@ if __name__ == '__main__':
 
 	if args.appName != None and len(args.appName) > 0:
 		for i in range(0, len(args.appName)):
-			if (sys.version_info.major == 3):
-				args.appName[i] = bytes(args.appName[i],'ascii')
-			if (sys.version_info.major == 2):
-				args.appName[i] = bytes(args.appName[i])
+			args.appName[i] = bytes(args.appName[i], 'ascii')
 
 	if args.appHash != None:
-		if (sys.version_info.major == 3):
-			args.appHash = bytes(args.appHash,'ascii')
-		if (sys.version_info.major == 2):
-			args.appHash = bytes(args.appHash)
+		args.appHash = bytes(args.appHash,'ascii')
 		args.appHash = bytearray.fromhex(args.appHash)
 
-
-	if args.targetId == None:
-		args.targetId = 0x31000002
 	if args.rootPrivateKey == None:
 		privateKey = PrivateKey()
 		publicKey = binascii.hexlify(privateKey.pubkey.serialize(compressed=False))
@@ -80,24 +70,21 @@ if __name__ == '__main__':
 			secret = getDeployedSecretV2(dongle, bytearray.fromhex(args.rootPrivateKey), args.targetId)
 	else:
 		fileTarget = open(args.offline, "wb")
-		class FileCard():
+		class FileCard:
 			def __init__(self, target):
 				self.target = target
 			def exchange(self, apdu):
-				if (args.apdu):
+				if args.apdu:
 					print(binascii.hexlify(apdu))
 				apdu = binascii.hexlify(apdu)
-				if sys.version_info.major == 2:
-					self.target.write(str(apdu) + '\n')
-				else:
-					self.target.write(apdu + '\n'.encode())
+				self.target.write(apdu + '\n'.encode())
 				return bytearray([])
 			def apduMaxDataSize(self):
 				# ensure to allow for encryption of those apdu afterward
 				return 240
 		dongle = FileCard(fileTarget)
 
-	loader = HexLoader(dongle, 0xe0, not(args.offline), secret)
+	loader = HexLoader(dongle, 0xe0, not args.offline, secret)
 
 	if args.appName != None and len(args.appName) > 0:
 		for name in args.appName:
