@@ -19,10 +19,7 @@
 
 from .ecWrapper import PrivateKey, PublicKey
 import os
-import sys
 import struct
-from .hexParser import IntelHexParser
-from .hexLoader import HexLoader
 import binascii
 
 def getDeployedSecretV1(dongle, masterPrivate, targetId):
@@ -101,7 +98,7 @@ def getDeployedSecretV2(dongle, masterPrivate, targetId, signerCertChain=None, e
 	#if cardKey != testMasterPublic:
 	#	raise Exception("Invalid batch public key")
 
-	if (signerCertChain):
+	if signerCertChain:
 		for cert in signerCertChain:
 			apdu = bytearray([0xE0, 0x51, 0x00, 0x00]) + bytearray([len(cert)]) + cert
 			dongle.exchange(apdu)
