@@ -19,16 +19,19 @@
 
 import argparse
 
+DEFAULT_ISSUER_KEY = "0490f5c9d15a0134bb019d2afd0bf297149738459706e7ac5be4abc350a1f818057224fce12ec9a65de18ec34d6e8c24db927835ea1692b14c32e9836a75dad609"
+
+
 def get_argparser():
 	parser = argparse.ArgumentParser(description="""Generate an attestation keypair, using the provided Owner private
 key to sign the Owner Certificate.""")
-	parser.add_argument("--key", help="Which endorsement scheme to use (1 or 2)", type=auto_int)
+	parser.add_argument("--key", help="Which endorsement scheme to use", type=auto_int, choices=(1, 2), required=True)
 	parser.add_argument("--certificate", help="""Optional certificate to store if finalizing the endorsement (hex
 encoded), if no private key is specified""")
 	parser.add_argument("--privateKey", help="""Optional private key to use to create a test certificate (hex encoded),
 if no certificate is specified""")
-	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int)
-	parser.add_argument("--issuerKey", help="Issuer key (hex encoded, default is batch 1)")
+	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int, default=0x31000002)
+	parser.add_argument("--issuerKey", help="Issuer key (hex encoded, default is batch 1)", default=DEFAULT_ISSUER_KEY)
 	parser.add_argument("--rootPrivateKey", help="SCP Host private key")
 	parser.add_argument("--apdu", help="Display APDU log", action='store_true')
 	return parser
@@ -36,13 +39,6 @@ if no certificate is specified""")
 def auto_int(x):
 		return int(x, 0)
 
-def hexstr(bstr):
-	if (sys.version_info.major == 3):
-		return binascii.hexlify(bstr).decode()
-	if (sys.version_info.major == 2):
-		return binascii.hexlify(bstr)
-	return ""
-
 def getDeployedSecretV2(dongle, masterPrivate, targetid, issuerKey):
 		testMaster = PrivateKey(bytes(masterPrivate))
 		testMasterPublic = bytearray(testMaster.pubkey.serialize(compressed=False))
@@ -123,19 +119,10 @@ if __name__ == '__main__':
 	import hashlib
 	import struct
 	import os
-	import sys
 	import binascii
 
 	args = get_argparser().parse_args()
 
-	if args.key == None:
-			raise Exception("Missing endorsement scheme number")
-	if args.key != 1 and args.key != 2:
-			raise Exception("Invalid endorsement scheme number")
-	if args.targetId == None:
-			args.targetId = 0x31000002
-	if args.issuerKey == None:
-			args.issuerKey = "0490f5c9d15a0134bb019d2afd0bf297149738459706e7ac5be4abc350a1f818057224fce12ec9a65de18ec34d6e8c24db927835ea1692b14c32e9836a75dad609"
 	if (args.privateKey != None) and (args.certificate != None):
 		raise Exception("Cannot specify both certificate and privateKey")
 
@@ -155,7 +142,7 @@ if __name__ == '__main__':
 	if args.certificate == None:
 			apdu = bytearray([0xe0, 0xC0, args.key, 0x00, 0x00])
 			response = dongle.exchange(apdu)
-			print("Public key " + hexstr(response[0:65]))
+			print("Public key " + response[0:65].hex())
 			m = hashlib.sha256()
 			m.update(bytes(b"\xff")) # Endorsement role
 			m.update(bytes(response[0:65]))
@@ -167,7 +154,7 @@ if __name__ == '__main__':
 				privateKey = PrivateKey(bytes(bytearray.fromhex(args.privateKey)))
 				dataToSign = bytes(bytearray([0xfe]) + response[0:65])
 				signature = privateKey.ecdsa_sign(bytes(dataToSign))
-				args.certificate = hexstr(privateKey.ecdsa_serialize(signature))
+				args.certificate = privateKey.ecdsa_serialize(signature).hex()
 
 	if args.certificate != None:
 			certificate = bytearray.fromhex(args.certificate)
