@@ -25,29 +25,22 @@ def get_argparser():
 	parser.add_argument("--apdu", help="Display APDU log", action='store_true')
 	parser.add_argument("--perso", help="""A reference to the personalization key; this is a reference to the specific
 Issuer keypair used by Ledger to sign the device's Issuer Certificate""", default="perso_11")
-	parser.add_argument("--firmware", help="A reference to the firmware to load")
-	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int)
-	parser.add_argument("--firmwareKey", help="A reference to the firmware key to use")
+	parser.add_argument("--firmware", help="A reference to the firmware to load", required=True)
+	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int, default=0x31000002)
+	parser.add_argument("--firmwareKey", help="A reference to the firmware key to use", required=True)
 	return parser
 
 def auto_int(x):
 	return int(x, 0)
 
-def hexstr(bstr):
-	if (sys.version_info.major == 3):
-		return binascii.hexlify(bstr).decode()
-	if (sys.version_info.major == 2):
-		return binascii.hexlify(bstr)
-	return ""
-
 def process(dongle, request):
 	response = {}
 	apdusList = []
 	try:
 		response['nonce'] = request['nonce']
-		if (request['query'] == "exchange"):
+		if request['query'] == "exchange":
 			apdusList.append(binascii.unhexlify(request['data']))
-		elif (request['query'] == "bulk"):
+		elif request['query'] == "bulk":
 			for apdu in request['data']:
 				apdusList.append(binascii.unhexlify(apdu))
 		else:
@@ -58,7 +51,7 @@ def process(dongle, request):
 	if len(apdusList) != 0:
 		try:
 			for apdu in apdusList:
-				response['data'] = hexstr(dongle.exchange(apdu))
+				response['data'] = dongle.exchange(apdu).hex()
 			if len(response['data']) == 0:
 				response['data'] = "9000"
 			response['response'] = "success"
@@ -68,31 +61,13 @@ def process(dongle, request):
 	return response			
 
 if __name__ == '__main__':
-	import sys
-	import os
-	import struct
-	if sys.version_info.major == 3:
-		import urllib.request as urllib2
-		import urllib.parse as urlparse
-	else:
-		import urllib2, urllib, urlparse	
+	import urllib.parse as urlparse
 	from .comm import getDongle
 	from websocket import create_connection
 	import json
 	import binascii
-	import sys
 
 	args = get_argparser().parse_args()
-	if args.url == None:
-		raise Exception("No URL specified")
-	if args.perso == None:
-		raise Exception("No personalization specified")
-	if args.firmware == None:
-		raise Exception("No firmware specified")
-	if args.firmwareKey == None:
-		raise Exception("No firmware key specified")
-	if args.targetId == None:
-		args.targetId = 0x31000002 # Ledger Blue by default
 
 	dongle = getDongle(args.apdu)
 
@@ -102,10 +77,7 @@ if __name__ == '__main__':
 	queryParameters['firmware'] = args.firmware
 	queryParameters['firmwareKey'] = args.firmwareKey
 	queryParameters['perso'] = args.perso
-	if sys.version_info.major == 3:
-  		queryString = urlparse.urlencode(queryParameters)
-	else:
-		queryString = urllib.urlencode(queryParameters)
+	queryString = urlparse.urlencode(queryParameters)
 	ws = create_connection(args.url + '?' + queryString)
 	while True:
 		result = json.loads(ws.recv())
